@@ -2,15 +2,14 @@ import base64
 import binascii
 import json
 import os
-
 from datetime import datetime, timezone
 from json.decoder import JSONDecodeError
 
-import requests
-from biolib.typing_utils import Optional
+from biolib._internal.http_client import HttpClient
+from biolib._runtime.runtime import Runtime
 from biolib.biolib_errors import BioLibError
 from biolib.biolib_logging import logger, logger_no_user_data
-from biolib.typing_utils import TypedDict, Dict, Any
+from biolib.typing_utils import Any, Dict, Optional, TypedDict
 
 from .user_state import UserState
 
@@ -29,13 +28,14 @@ class _ApiClient:
         self.base_url: str = base_url
         self.access_token: Optional[str] = access_token  # TODO: Deprecate passing access_token in constructor
         self.refresh_token: Optional[str] = None
+        self.resource_deploy_key: Optional[str] = None
 
         self._user_state = UserState()
         self._sign_in_attempted: bool = False
 
     @property
     def is_signed_in(self) -> bool:
-        return bool(self.refresh_token)
+        return bool(self.refresh_token or self.resource_deploy_key)
 
     def set_user_tokens(self, user_tokens: UserTokens) -> None:
         with self._user_state as user_state:
@@ -56,31 +56,31 @@ class _ApiClient:
             user_state['refresh_token'] = None
 
     def refresh_access_token(self) -> None:
-        if not self.is_signed_in:
-            # Can't refresh access token if not signed in
+        if not self.is_signed_in or self.resource_deploy_key:
             return
 
         if self.access_token:
-            decoded_token = self._decode_jwt_without_checking_signature(self.access_token)
+            decoded_token = self.decode_jwt_without_checking_signature(self.access_token)
             if datetime.now(tz=timezone.utc).timestamp() < decoded_token['payload']['exp'] - 60:  # 60 second buffer
                 # Token has not expired yet
                 return
 
         # TODO: Implement nicer error handling
-        response = requests.post(
-            url=f'{self.base_url}/api/user/token/refresh/',
-            timeout=5,
-            json={'refresh': self.refresh_token},
-        )
+        try:
+            response = HttpClient.request(
+                method='POST',
+                url=f'{self.base_url}/api/user/token/refresh/',
+                data={'refresh': self.refresh_token},
+            )
+        except Exception as exception:
+            logger.error('Sign in with refresh token failed')
+            raise exception
+
         try:
             response_dict = response.json()
         except JSONDecodeError as error:
             logger.error('Could not decode response from server as JSON:')
             raise BioLibError(response.text) from error
-        if not response.ok:
-            error_message = f'Sign in with refresh token failed: {response_dict.get("detail")}'
-            logger.error(error_message)
-            raise BioLibError(error_message)
 
         self.access_token = response_dict['access']
 
@@ -93,7 +93,10 @@ class _ApiClient:
         api_token = os.getenv('BIOLIB_TOKEN', default=None)
 
         if api_token:
-            self.sign_in_with_api_token(api_token)
+            if api_token.startswith('bld_'):
+                self.resource_deploy_key = api_token
+            else:
+                self.sign_in_with_api_token(api_token)
         else:
             with self._user_state as user_state:
                 refresh_token_from_state = user_state['refresh_token']
@@ -111,25 +114,26 @@ class _ApiClient:
 
     def sign_in_with_api_token(self, api_token: str) -> None:
         logger_no_user_data.debug('ApiClient: Signing in with BIOLIB_TOKEN...')
-        response = requests.post(
-            url=f'{self.base_url}/api/user/api_tokens/exchange/',
-            json={'token': api_token},
-            timeout=5,
-        )
+        try:
+            response = HttpClient.request(
+                method='POST',
+                url=f'{self.base_url}/api/user/api_tokens/exchange/',
+                data={'token': api_token},
+            )
+        except Exception as exception:
+            logger.error('Sign in with API token failed')
+            raise exception
         try:
             json_response = response.json()
         except JSONDecodeError as error:
             logger.error('Could not decode response from server as JSON')
             raise BioLibError(response.text) from error
-        if not response.ok:
-            logger.error('Sign in with API token failed')
-            raise BioLibError(json_response['detail'])
-        else:
-            self.access_token = json_response['access_token']
-            self.refresh_token = json_response['refresh_token']
+
+        self.access_token = json_response['access_token']
+        self.refresh_token = json_response['refresh_token']
 
     @staticmethod
-    def _decode_jwt_without_checking_signature(jwt: str) -> Dict[str, Any]:
+    def decode_jwt_without_checking_signature(jwt: str) -> Dict[str, Any]:
         jwt_bytes = jwt.encode('utf-8')
 
         try:
@@ -175,10 +179,11 @@ class BiolibApiClient:
         BiolibApiClient.api_client = _ApiClient(base_url=base_url, access_token=access_token)
 
     @staticmethod
-    def get() -> _ApiClient:
+    def get(attempt_sign_in: bool = True) -> _ApiClient:
         api_client = BiolibApiClient.api_client
         if api_client:
-            api_client.attempt_sign_in()
+            if attempt_sign_in:
+                api_client.attempt_sign_in()
             return api_client
 
         raise BioLibError('Attempted to use uninitialized API client')
@@ -189,9 +194,16 @@ class BiolibApiClient:
         api_client.refresh_access_token()
 
     @staticmethod
-    def assert_is_signed_in(authenticated_action_description: str) -> None:
+    def is_reauthentication_needed() -> bool:
         api_client = BiolibApiClient.get()
-        if not api_client.is_signed_in:
+        if not api_client.is_signed_in and not Runtime.check_is_environment_biolib_app():
+            return True
+        else:
+            return False
+
+    @staticmethod
+    def assert_is_signed_in(authenticated_action_description: str) -> None:
+        if BiolibApiClient.is_reauthentication_needed():
             raise BioLibError(
                 f'You must be signed in to {authenticated_action_description}. '
                 f'Please set the environment variable "BIOLIB_TOKEN"'
