@@ -68,11 +68,6 @@ class LargeFileSystemMapping(TypedDict):
     uuid: str
 
 
-class PortMapping(TypedDict):
-    from_port: int
-    to_port: int
-
-
 class _Module(TypedDict):
     command: str
     environment: Literal['biolib-app', 'biolib-custom', 'biolib-ecr']
@@ -83,7 +78,7 @@ class _Module(TypedDict):
     large_file_systems: List[LargeFileSystemMapping]
     name: str
     output_files_mappings: List[FilesMapping]
-    port_mappings: List[PortMapping]
+    ports: List[int]
     source_files_mappings: List[FilesMapping]
     working_directory: str
 
