@@ -9,8 +9,7 @@ from biolib.biolib_docker_client import BiolibDockerClient
 from biolib.biolib_errors import BioLibError
 from biolib.biolib_logging import logger_no_user_data
 from biolib.compute_node.job_worker.cache_state import DockerImageCacheState, DockerCacheStateError
-from biolib.compute_node.job_worker.cache_types import DockerImageInfo, DockerImageCacheStateDict, DockerAuthConfig, \
-    UuidStr
+from biolib.compute_node.job_worker.cache_types import DockerImageInfo, DockerImageCacheStateDict, UuidStr
 
 
 class DiskUsage(TypedDict):
@@ -70,7 +69,6 @@ class DockerImageCache:
             self,
             image_uri: str,
             estimated_image_size_bytes: int,
-            pull_auth_config: DockerAuthConfig,
             job_id: str,
     ) -> None:
         try:
@@ -106,7 +104,7 @@ class DockerImageCache:
 
             logger_no_user_data.debug(f'Image {image_uri} not found in cache. Pulling...')
             try:
-                self._docker_client.images.pull(image_uri, auth_config=pull_auth_config)
+                self._docker_client.images.pull(image_uri)
             except Exception as error:
                 logger_no_user_data.error(f'Could not pull image due to {error}')
 
