@@ -11,10 +11,10 @@ import zipfile
 from copy import copy
 from datetime import datetime
 
-import docker  # type: ignore
-import docker.types  # type: ignore
-from docker.errors import APIError, ImageNotFound  # type: ignore
-from docker.models.containers import Container  # type: ignore
+import docker
+import docker.types
+from docker.errors import APIError, ImageNotFound
+from docker.models.containers import Container
 
 from biolib import utils
 from biolib._internal.runtime import RuntimeJobDataDict
@@ -40,7 +40,7 @@ class DockerExecutor:
         self._options: LocalExecutorOptions = options
         self._is_cleaning_up = False
 
-        self._absolute_image_uri = f"{utils.BIOLIB_SITE_HOSTNAME}/{self._options['module']['image_uri']}"
+        self._absolute_image_uri = f'{utils.BIOLIB_SITE_HOSTNAME}/{self._options["module"]["image_uri"]}'
         self._send_system_exception = options['send_system_exception']
         self._send_stdout_and_stderr = options['send_stdout_and_stderr']
         self._random_docker_id = compute_node_utils.random_string(15)
@@ -308,7 +308,8 @@ class DockerExecutor:
             job_uuid = self._options['job']['public_id']
             logger_no_user_data.debug(f'Job "{job_uuid}" initializing Docker container...')
             module = self._options['module']
-            logger.debug(f"Initializing docker container with command: {module['command']}")
+            logger.debug(f'Initializing docker container with command: {module["command"]}')
+            docker_client = BiolibDockerClient.get_docker_client()
 
             docker_volume_mounts = [lfs.docker_mount for lfs in self._options['large_file_systems'].values()]
 
@@ -391,6 +392,9 @@ class DockerExecutor:
                 'mounts': docker_volume_mounts,
                 'network': internal_network.name,
                 'working_dir': module['working_directory'],
+                'networking_config': {
+                    internal_network.name: docker_client.api.create_endpoint_config(aliases=['main'])
+                },
             }
 
             if self._options['job'].get('arguments_override_command'):
@@ -429,7 +433,6 @@ class DockerExecutor:
             if docker_runtime is not None:
                 create_container_args['runtime'] = docker_runtime
 
-            docker_client = BiolibDockerClient.get_docker_client()
             logger_no_user_data.debug(f'Job "{job_uuid}" initializing Docker container. Creating container...')
             self._docker_container = docker_client.containers.create(**create_container_args)
             logger_no_user_data.debug(f'Job "{job_uuid}" finished initializing Docker container.')
