@@ -80,7 +80,6 @@ class JobWorker:
 
             self._remote_host_proxies: List[RemoteHostProxy] = []
             self._internal_network: Optional[Network] = None
-            self._public_network: Optional[Network] = None
             self._executors: List[DockerExecutor] = []
             self.is_cleaning_up: bool = False
 
@@ -217,8 +216,6 @@ class JobWorker:
         logger_no_user_data.debug('Cleaning up networks...')
         self._cleanup_network(self._internal_network)
         self._internal_network = None
-        self._cleanup_network(self._public_network)
-        self._public_network = None
         logger_no_user_data.debug('Cleaned up networks...')
 
     @staticmethod
@@ -253,10 +250,10 @@ class JobWorker:
         app_version = job['app_version']
         modules = app_version.get('modules', [])
         for module in modules:
-            module_port_mappings = module.get('port_mappings', [])
-            if module_port_mappings:
+            module_ports = module.get('ports', [])
+            if module_ports:
                 logger_no_user_data.debug(
-                    f"Job '{job['public_id']}' module '{module['name']}' has port_mappings: {module_port_mappings}"
+                    f"Job '{job['public_id']}' module '{module['name']}' has ports: {module_ports}"
                 )
 
         if job['app_version'].get('modules') is not None and BiolibDockerClient.is_docker_running():
@@ -291,20 +288,6 @@ class JobWorker:
             ) from exception
 
         if len(remote_hosts) > 0:
-            logger_no_user_data.debug(f'Job "{job_id}" creating networks for remote host proxies...')
-            try:
-                self._public_network = docker_client.networks.create(
-                    name=f'biolib-proxy-network-{job_id}',
-                    internal=False,
-                    driver='bridge',
-                )
-            except Exception as exception:
-                raise ComputeProcessException(
-                    exception,
-                    SystemExceptionCodes.FAILED_TO_CREATE_DOCKER_NETWORKS.value,
-                    self.send_system_exception,
-                    may_contain_user_data=False
-                ) from exception
             logger_no_user_data.debug(f'Job "{job_id}" starting proxies for remote hosts: {remote_hosts}')
             try:
                 hostname_to_ports: Dict[str, List[int]] = {}
@@ -323,11 +306,10 @@ class JobWorker:
 
                 for hostname, ports in hostname_to_ports.items():
                     remote_host_proxy = RemoteHostProxy(
-                        RemoteHost(hostname=hostname),
-                        self._public_network,
-                        self._internal_network,
-                        job_id,
-                        ports,
+                        remote_host=RemoteHost(hostname=hostname),
+                        internal_network=self._internal_network,
+                        job_id=job_id,
+                        ports=ports,
                     )
                     remote_host_proxy.start()
                     self._remote_host_proxies.append(remote_host_proxy)
