@@ -56,17 +56,13 @@ class LargeFileSystem:
         self._path_on_disk_for_write: Optional[str] = None
         self._send_status_update: Callable[[StatusUpdate], None] = send_status_update
 
-    @property
-    def _is_initialized(self) -> bool:
-        return self._path_on_disk is not None
-
     @property
     def uuid(self) -> str:
         return self._lfs_mapping['uuid']
 
     @property
     def docker_mount(self) -> docker.types.Mount:
-        if not self._is_initialized:
+        if not self._path_on_disk:
             raise LargeFileSystemError('LargeFileSystem not initialized')
 
         return docker.types.Mount(
@@ -77,7 +73,7 @@ class LargeFileSystem:
         )
 
     def initialize(self) -> None:
-        if self._is_initialized:
+        if self._path_on_disk:
             logger_no_user_data.debug(f'LFS {self.uuid} is already initialized')
             return
 
